package com.jjt.inventory.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.inventory.domain.TwinCalcHourBpOut;
import com.jjt.inventory.service.ITwinCalcHourBpOutService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 白坯投放量小时数据Controller
 *
 * @author wukai
 * @date 2025-06-11
 */
@Api(tags="白坯投放量小时数据")
@RestController
@RequestMapping("/inventory/out")
public class TwinCalcHourBpOutController extends BaseController{
    @Resource
    private ITwinCalcHourBpOutService twinCalcHourBpOutService;

    /**
     * 查询白坯投放量小时数据列表
     */
    @ApiOperation("查询白坯投放量小时数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:out:list')")
    @GetMapping("/list")
    public TableDataInfo list(TwinCalcHourBpOut twinCalcHourBpOut)
    {
        startPage();
        List<TwinCalcHourBpOut> list = twinCalcHourBpOutService.selectTwinCalcHourBpOutList(twinCalcHourBpOut);
        return getDataTable(list);
    }

    /**
     * 导出白坯投放量小时数据列表
     */
    @ApiOperation("导出白坯投放量小时数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:out:export')")
    @Log(title = "白坯投放量小时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TwinCalcHourBpOut twinCalcHourBpOut)
    {
        List<TwinCalcHourBpOut> list = twinCalcHourBpOutService.selectTwinCalcHourBpOutList(twinCalcHourBpOut);
        ExcelUtil<TwinCalcHourBpOut> util = new ExcelUtil<TwinCalcHourBpOut>(TwinCalcHourBpOut.class);
        util.exportExcel(response, list, "白坯投放量小时数据数据");
    }

    /**
     * 获取白坯投放量小时数据详细信息
     */
    @ApiOperation("获取白坯投放量小时数据详细信息")
    //@PreAuthorize("@ss.hasPermi('inventory:out:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(twinCalcHourBpOutService.selectTwinCalcHourBpOutById(id));
    }

    /**
     * 新增白坯投放量小时数据
     */
    @ApiOperation("新增白坯投放量小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:out:add')")
    @Log(title = "白坯投放量小时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TwinCalcHourBpOut twinCalcHourBpOut)
    {
        return toAjax(twinCalcHourBpOutService.insertTwinCalcHourBpOut(twinCalcHourBpOut));
    }

    /**
     * 修改白坯投放量小时数据
     */
    @ApiOperation("修改白坯投放量小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:out:edit')")
    @Log(title = "白坯投放量小时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TwinCalcHourBpOut twinCalcHourBpOut)
    {
        return toAjax(twinCalcHourBpOutService.updateTwinCalcHourBpOut(twinCalcHourBpOut));
    }

    /**
     * 删除白坯投放量小时数据
     */
    @ApiOperation("删除白坯投放量小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:out:remove')")
    @Log(title = "白坯投放量小时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(twinCalcHourBpOutService.deleteTwinCalcHourBpOutByIds(ids));
    }
}
